<?php

namespace Accept_Stripe_Payments\Cust_Msg;

class Admin {

	public $plugin_slug;
	public $asp_admin;
	public $helper;

	public function __construct( $helper ) {
		$this->asp_admin   = \AcceptStripePayments_Admin::get_instance();
		$this->plugin_slug = $this->asp_admin->plugin_slug;
		$this->helper      = $helper;
		add_action( 'admin_init', array( $this, 'register_settings' ) );
		add_action( 'asp-settings-page-after-tabs-menu', array( $this, 'after_tabs_menu' ) );
		add_action( 'asp-settings-page-after-tabs', array( $this, 'after_tabs' ) );
		add_filter( 'asp-admin-settings-addon-field-display', array( $this, 'field_display' ), 10, 2 );
		add_filter( 'apm-admin-settings-sanitize-field', array( $this, 'sanitize_settings' ), 10, 2 );
	}

	public function sanitize_settings( $output, $input ) {

		$output['custmsg_enabled'] = isset( $input['custmsg_enabled'] ) ? 1 : 0;

		$output['custmsg_messages'] = isset( $_POST['asp_custmsg_messages'] ) ? json_encode( $_POST['asp_custmsg_messages'] ) : false;

		return $output;
	}

	public function field_display( $field, $field_value ) {
		$ret = array();
		switch ( $field ) {
			case 'custmsg_enabled':
				$ret['field']      = 'checkbox';
				$ret['field_name'] = $field;
				break;
			case 'custmsg_messages':
				$out         = '<p class="description">' . __( 'Customize messages below as per your requirements.', 'stripe-payments' ) . '</p>';
				$out        .= '<table>';
				$tpl         = '<tr><th>%2$s</th><td><input type="text" style="width: 100%%;" name="asp_custmsg_messages[%1$s]" value="%3$s"></td></tr>';
				$settings    = get_option( 'AcceptStripePayments-settings' );
				$field_value = isset( $settings['custmsg_messages'] ) ? $settings['custmsg_messages'] : false;
				if ( ! empty( $field_value ) ) {
					$curr_values = json_decode( $field_value, true );
				} else {
					$curr_values = array();
				}
				foreach ( $this->helper->addon->msgs as $key => $value ) {
					$out .= sprintf( $tpl, $key, $value, isset( $curr_values[ $key ] ) ? esc_attr( stripslashes( $curr_values[ $key ] ) ) : $value );
				}
				$out              .= '</table>';
				$ret['field']      = 'custom';
				$ret['field_name'] = $field;
				$ret['field_data'] = $out;
				break;
		}
		if ( ! empty( $ret ) ) {
			return $ret;
		} else {
			return $field;
		}
	}

	public function register_settings() {
		$this->helper->add_settings_section( __( 'Custom Messages Settings', 'stripe-payments' ) );
		$this->helper->add_settings_field( 'custmsg_enabled', __( 'Enable Custom Messages', 'stripe-payments' ), __( 'Enables custom messages.', 'stripe-payments' ) );
		$this->helper->add_settings_field( 'custmsg_messages', __( 'Messages', 'stripe-payments' ), '' );
	}

	public function after_tabs_menu() {
		?>
	<a href="#<?php echo $this->helper->addon->SETTINGS_TAB_NAME; ?>" data-tab-name="<?php echo $this->helper->addon->SETTINGS_TAB_NAME; ?>" class="nav-tab"><?php echo __( 'Custom Messages', 'stripe-payments' ); ?></a>
		<?php
	}

	public function after_tabs() {
		?>
	<div class="wp-asp-tab-container asp-custom-msg-container" data-tab-name="<?php echo $this->helper->addon->SETTINGS_TAB_NAME; ?>">
		<?php do_settings_sections( $this->plugin_slug . '-' . $this->helper->addon->SETTINGS_TAB_NAME ); ?>
	</div>
		<?php
	}

}
