<?php
/**
 * Plugin Name: Stripe Payments Custom Messages Addon
 * Plugin URI: https://s-plugins.com/stripe-payments-custom-messages-addon/
 * Description: Allows you to easily customize the various messages displayed by the main Stripe payments plugin.
 * Version: 1.0.7
 * Author: Tips and Tricks HQ, alexanderfoxc
 * Author URI: https://s-plugins.com/
 * License: GPL2
 */

namespace Accept_Stripe_Payments\Cust_Msg;

if ( ! defined( 'ABSPATH' ) ) {
	exit; //Exit if accessed directly
}

class Main {

	public $helper;
	public $file;
	public $ADDON_SHORT_NAME  = 'CustMsg';
	public $ADDON_FULL_NAME   = 'Stripe Payments Custom Messages Addon';
	public $MIN_ASP_VER       = '1.9.0';
	public $SLUG              = 'stripe-payments-custom-messages';
	public $SETTINGS_TAB_NAME = 'custmsg';
	public $msgs;

	public function __construct() {
		$this->file = __FILE__;
		$this->msgs = array(
			'enter_amount'            => __( 'Enter amount', 'stripe-payments' ),
			'enter_valid_amount'      => __( 'Please enter a valid amount', 'stripe-payments' ),
			'fill_in_field'           => __( 'Please fill in this field.', 'stripe-payments' ),
			'accept_terms'            => __( 'You must accept the terms before you can proceed.', 'stripe-payments' ),
			'quantity_is_zero'        => __( 'Quantity can\'t be zero.', 'stripe-payments' ),
			'quantity_is_float'       => __( 'Quantity should be integer value.', 'stripe-payments' ),
			'min_amount_is'           => __( 'Minimum amount is', 'stripe-payments' ),
			'enter_quantity'          => __( 'Please enter quantity.', 'stripe-payments' ),
			'tax_str'                 => __( 'Tax', 'stripe-payments' ),
			'shipping_str'            => __( 'Shipping', 'stripe-payments' ),
			'start_free_trial'        => __( 'Start Free Trial', 'stripe-payments' ),
			'pp_coupon_code'          => __( 'Coupon Code', 'stripe-payments' ),
			'pp_credit_or_debit_card' => __( 'Credit or debit card', 'stripe-payments' ),
			'pp_billing_name'         => __( 'Name', 'stripe-payments' ),
			'pp_email'                => __( 'Email', 'stripe-payments' ),
                        'pp_billing_state'        => __( 'State', 'stripe-payments' ),
                        'pp_billing_postcode'     => __( 'Postcode', 'stripe-payments' ),
                        'pp_shipping_state'       => __( 'Shipping State', 'stripe-payments' ),
                        'pp_shipping_postcode'    => __( 'Shipping Postcode', 'stripe-payments' ),
		);
		add_action( 'plugins_loaded', array( $this, 'plugins_loaded' ) );
	}

	public function plugins_loaded() {
		if ( class_exists( 'AcceptStripePayments' ) ) {
			$this->helper = new \ASPAddonsHelper( $this );
			//check minimum required core plugin version
			if ( ! $this->helper->check_ver() ) {
				return false;
			}
			$this->helper->init_tasks();

			if ( \AcceptStripePayments::get_instance()->get_setting( 'custmsg_enabled' ) ) {
				add_filter( 'asp_customize_text_msg', array( $this, 'process_custom_msg' ), 10, 2 );
			}
			if ( is_admin() ) {
				include_once plugin_dir_path( $this->file ) . 'admin/class-admin.php';
				new Admin( $this->helper );
			}
		}
	}

	public function process_custom_msg( $msg, $key ) {
		$settings    = get_option( 'AcceptStripePayments-settings' );
		$field_value = isset( $settings['custmsg_messages'] ) ? $settings['custmsg_messages'] : false;
		if ( ! empty( $field_value ) ) {
			$curr_values = json_decode( $field_value, true );
			if ( isset( $curr_values[ $key ] ) ) {
				$msg = stripslashes( $curr_values[ $key ] );
			}
		}
		return $msg;
	}

}

new Main();
